summaryrefslogtreecommitdiff
path: root/test/unit/util/integer_white.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/util/integer_white.cpp')
-rw-r--r--test/unit/util/integer_white.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/util/integer_white.cpp b/test/unit/util/integer_white.cpp
index 16e606d87..3b5363dda 100644
--- a/test/unit/util/integer_white.cpp
+++ b/test/unit/util/integer_white.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief White box testing of CVC4::Integer.
**
** White box testing of CVC4::Integer.
**/
#include <sstream>
@@ -19,7 +19,7 @@
#include "test.h"
#include "util/integer.h"
-namespace CVC4 {
+namespace CVC5 {
namespace test {
class TestUtilWhiteInteger : public TestInternal
@@ -53,4 +53,4 @@ TEST_F(TestUtilWhiteInteger, construction)
ASSERT_EQ(Integer(u), Integer(u));
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief White box testing of CVC4::Integer.
+ ** \brief White box testing of CVC5::Integer.
**
@@ -9,9 +9,9 @@
**
- ** White box testing of CVC4::Integer.
+ ** White box testing of CVC5::Integer.
**/
#include <sstream>